#
# spec file for package gap-rcwa
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           gap-rcwa
Version:        4.7.1
Release:        1.4
Summary:        GAP: Residue-Class-Wise Affine Groups
License:        GPL-2.0-or-later
Group:          Productivity/Scientific/Math
URL:            https://gap-packages.github.io/rcwa/
#Git-Clone:     https://github.com/gap-packages/rcwa
Source:         https://github.com/gap-packages/rcwa/releases/download/v%version/rcwa-%version.tar.gz
BuildArch:      noarch
BuildRequires:  gap-rpm-devel
Requires:       gap-core >= 4.9.1
Requires:       gap-fr >= 2.2.1
Requires:       gap-gapdoc >= 1.5.1
Requires:       gap-grape >= 4.7
Requires:       gap-polycyclic >= 2.11
Requires:       gap-resclasses >= 4.7.2
Requires:       gap-utils >= 0.40

%description
This package for GAP 4 introduces a new class of groups which are
accessible to computational methods. In principle, it can deal at
least with the follo- wing types of groups:

* Finite groups.
* Free groups of finite rank.
* Free products of finitely many finite groups, thus in particular
  the modular group PSL(2,Z).
* Direct products of such groups.
* Wreath products of such groups with finite groups and with (Z,+).

Among these groups there are finitely generated groups which are not
finitely presented, and such with unsolvable membership problem.
Further, any finite group embeds into some divisible torsion group
which RCWA can deal with.

%prep
%autosetup -n rcwa-%version

%build

%install
%gappkg_simple_install

%files -f %name.files

%changelog
* Sun Feb 12 2023 Jan Engelhardt <jengelh@inai.de>
- Update to release 4.7.1
  * An operation `CTCSCRSplit` has been added.
  * Fixed some issues where loading ResClasses could inadvertently
    alter the behavior of GAP library functions.
  * An operation `TryToComputeDegreeOfTransitivity` has been added,
    together with a method for rcwa groups over Z.
  * An operation `SupersetOfOrbitRepresentatives` has been added,
    together with a method for subgroups of CT(Z).
  * An operation `ResidueClassCyclesThroughResidueClass` has been
    added, together with a method for rcwa permutations of Z.
  * An operation `DrawResidueClassCyclesThroughResidueClassPicture`
    has been added, together with a method for rcwa permutations of
    Z.
  * Components `growthsequences`, `abelian`, `metabelian`,
    `solvable`, `abelianinvariants` and `compositionfactors` have
    been added to the database of groups generated by 3 class
    transpositions interchanging residue classes with moduli <= 6.
  * Added a global switch `CTSparse` to choose sparse
    representation for class transpositions of Z.
* Sat Feb  3 2018 jengelh@inai.de
- Update to new upstream release 4.6.1
  * No user-visible changes (only pkg metadata)
* Mon Dec 25 2017 jengelh@inai.de
- Update to new upstream release 4.6.0
  * Determining transitivity and computing transitivity
    certificates has been made more efficient in some cases, and
    an operation `SimplifiedCertificate' has been added.
  * An operation `EpimorphismsUpToAutomorphisms' has been added,
    together with a method which computes all epimorphisms from a
    given finitely presented group to a given finite group up to
    automorphisms of the latter.
  * Lists 'redundant_generator', 'spheresizebound_4',
    'spheresizebound_6', 'spheresizebound_12' and
    'spheresizebound_24' have been added to the database of
    groups generated by 3 class transpositions.
  * Single-argument methods for `TransitionMatrix' and
    `TransitionGraph' have been added.
* Sat Apr 29 2017 jengelh@inai.de
- Update to new upstream release 4.5.1
  * RCWA now prints a warning if GAP is run in legacy 32-bit mode
    due to the size of integers in ranges in 32-bit GAP which may
    make some computations fail and trigger error messages.
  * A further method for `EpimorphismFromFpGroup' has been added.
    This method allows to limit the search space to elements with
    not more than a given number of affine parts.
  * Attributes
    `DecompositionIntoPermutationalAndOrderPreservingElement' and
    `SignInOddCTPZ' have been added.
  * The following components have been added to the database of
    groups generated by 3 class transpositions:
    'minwordlengthnonbalanced', 'minwordlengthcoprimemultdiv',
    'epifromfpgrouptocollatzgroup_c' and
    'epifromfpgrouptocollatzgroup_t'.
  * The method for `RestrictedBall' for computing restricted
    balls in rcwa monoids does now interpret options
    "boundaffineparts" and "boundnonidentityaffineparts". If set,
    the specified bound is on the number of affine parts,
    respectively, on the number of affine parts distinct from the
    identity, rather than on the modulus of the mapping.
  * An operation `HashValueOfRcwaMapping' has been added. The
    purpose of the hash values is to allow faster searching of
    rcwa mappings by algorithms.
  * Now the operations `Support', `IncreasingOn', `DecreasingOn',
    `ShiftsUpOn', `ShiftsDownOn',
    `LargestSourcesOfAffineMappings' and `Multpk' return their
    result in sparse representation if the argument is in sparse
    representation.
  * An operation `RefinementSequence' has been added.
* Mon Jun 20 2016 jengelh@inai.de
- Update to new upstream release 4.4.1
  * A `Random` method for finitely generated rcwa groups and given
  word length has been added.
  * Many newly found subgroup relations have been added to the
  database of groups generated by 3 class transpositions which
  interchange residue classes with moduli <= 6.
  * A new method for computing the order of an element of CT(Z) has
  been added. Its use can be triggered by setting the option
  "new_order" when calling the operation `Order`. This method is
  sometimes faster and sometimes slower than the default method.
  * The function `PrimeSwitch' has been turned into an operation,
  and new methods PrimeSwitch(p,r,m) and PrimeSwitch(p,cl) to
  construct "residue class specific" prime switches have been
  added.
  * The functions for loading the databases of rcwa groups and
  - mappings do no longer return the content of the respective
  database itself, but just the name of the variable which the
  database record is assigned to. Hence forgetting the ';;' at
  the end of the line when loading one of the databases does no
  longer result in megabytes of data printed to the screen.
  * Selector functions `All3CTs9Groups' and `All3CTs9Indices' have
  been added to the database of groups generated by 3 class
  transpositions interchanging residue classes with moduli <= 9.
  * The meaning of CT(P,Integers) has been changed in that 2 is no
  longer treated as a special case, and P is now the full prime
  set of the constructed group. -- That means e.g. that the
  former CT([],Integers) is now CT([2],Integers).
  * There is now a generating set for CT([2,3],Integers) consisting
  of only 6 class transpositions known, instead of 14 as before.
  Also, a generating set for CT([3],Integers) has been added.
  * A method for `ExtRepOfObj' for class transpositions has been
  added. This method returns the 4-tuple [r1,m1,r2,m2]
  corresponding to the interchanged residue classes r1(m1) and
  r2(m2).
* Wed Jun  8 2016 jengelh@inai.de
- Update to new upstream release 4.3.1
  * The propagation of the knowledge about bijectivity to inverses of
  bijective rcwa mappings is now taken care of by RCWA. -- Until GAP
  4.8.1, this was done by the GAP Library.
* Sat Mar 12 2016 jengelh@inai.de
- Update to new upstream release 4.0.0
  * A database of groups generated by 3 class transpositions
  intechanging residue classes with moduli <= 9 has been added. For
  each of these 3031864 groups, the modulus and the order are
  stored. Also, for all finite ones among these groups, the length
  of the shortest respected partition is stored.
  * The following data has been added to the database of groups
  generated by 3 class transpositions:
  * data on subgroup- and supergroup relations between the groups in
  the database (lists 'subgroups' and 'supergroups'),
  * data on the orbit growth functions (list 'orbitgrowthtype'),
  * lists of lengths of short finite orbits of residue classes, and
  * data on sphere size cycles for orbits with periodic growth
  function.
  * RCWA makes now use of the new sparse representation of residue
  class unions implemented in ResClasses 4.0.0.
* Fri Dec 12 2014 jengelh@inai.de
- Update to new upstream release 3.7.0
  * An operation "MergerExtension" has been added. This operation
  constructs a certain infinite extension of a given transitive
  finite permutation group.
  * The manual section "Constructing residue-class-wise affine
  groups" has been revised.
  * The function "DrawOrbitPicture" has been improved, and in
  particular been made more efficient. The meaning of one of its
  arguments has changed.
  * Functions "EncryptIntoBitmapPicture" and
  "DecryptFromBitmapPicture" for steganography in bitmap pictures
  have been added.
  * A function "ShrinkMonochromePictureToGrayscalesPicture" has been added.
  This function is for producing smaller greyscale pictures from large
  monochrome pictures.
* Fri Feb  7 2014 jengelh@inai.de
- Update to new upstream release 3.6.1
  * Considerable additions to the database of groups
  generated by 3 class transpositions have been made
  * A database of pairs of class transpositions interchanging residue
  classes with moduli <= 12 sorted by the order of their product
  has been added.
  * A database similar to the one mentioned before up to modulus 32,
  but restricted to orders 8, 24, 40, 42, 84, 120, 168 and 420 has
  been added.
  * There is now an operation `Mirrored' which applies the automorphism
  conjugating with n |-> -n - 1 to an rcwa mapping of Z or an rcwa
  group over Z. This interchanges the action on negative and
  nonnegative integers.
  * A basic method for `RepresentativeAction' has been added which
  computes an rcwa permutation g such that G^g = H for given
  conjugate rcwa groups G, H < RCWA(Z).
  * A bug has been fixed which caused error messages when computing
  with rcwa mappings of Z in sparse representation which were not
  class-wise order-preserving.
* Fri May 10 2013 jengelh@inai.de
- Split rcwa (version 3.5.1) off the gap RPM package
